summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/classgenpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/classgenpage.h')
-rw-r--r--umbrello/umbrello/dialogs/classgenpage.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/dialogs/classgenpage.h b/umbrello/umbrello/dialogs/classgenpage.h
index d6d06a50..fed32a2d 100644
--- a/umbrello/umbrello/dialogs/classgenpage.h
+++ b/umbrello/umbrello/dialogs/classgenpage.h
@@ -45,29 +45,29 @@ public:
* Sets up the ClassGenPage.
*
* @param d The UMLDoc which controls controls object creation.
* @param tqparent The tqparent to the ClassGenPage.
* @param o The UMLObject to display the properties of.
*/
- ClassGenPage(UMLDoc *d, TQWidget *tqparent, UMLObject * o);
+ ClassGenPage(UMLDoc *d, TQWidget *parent, UMLObject * o);
/**
* Sets up the ClassGenPage for an ObjectWidget
*
* @param d The UMLDoc which controls controls object creation.
* @param tqparent The tqparent to the ClassGenPage.
* @param o The ObjectWidget to display the properties of.
*/
- ClassGenPage(UMLDoc *d, TQWidget *tqparent, ObjectWidget * o);
+ ClassGenPage(UMLDoc *d, TQWidget *parent, ObjectWidget * o);
/**
* Sets up the ClassGenPage for a UMLWidget instance (used
* for component instances on deployment diagrams)
*
* @param d The UMLDoc which controls controls object creation.
* @param tqparent The tqparent to the ClassGenPage.
* @param widget The UMLWidget to display the properties of.
*/
- ClassGenPage(UMLDoc* d, TQWidget* tqparent, UMLWidget* widget);
+ ClassGenPage(UMLDoc* d, TQWidget* parent, UMLWidget* widget);
/**
* Standard deconstructor.
@@ -45,29 +45,29 @@ public:
*
* @param d The UMLDoc which controls controls object creation.
- * @param tqparent The tqparent to the ClassGenPage.
+ * @param parent The parent to the ClassGenPage.
* @param o The UMLObject to display the properties of.
*/
@@ -45,29 +45,29 @@ public:
*
* @param d The UMLDoc which controls controls object creation.
- * @param tqparent The tqparent to the ClassGenPage.
+ * @param parent The parent to the ClassGenPage.
* @param o The ObjectWidget to display the properties of.
*/
@@ -45,29 +45,29 @@ public:
*
* @param d The UMLDoc which controls controls object creation.
- * @param tqparent The tqparent to the ClassGenPage.
+ * @param parent The parent to the ClassGenPage.
* @param widget The UMLWidget to display the properties of.
*/